@@ -279,6 +279,7 @@ static int DidAMonth;
 static int DidAWeek;
 static int DidADay;
 
+static char const *CalendarTime(int tim, int duration);
 static void ColorizeEntry(CalEntry const *e, int clamp);
 static void SortCol (CalEntry **col);
 static void DoCalendarOneWeek (int nleft);
@@ -288,7 +289,7 @@ static int WriteCalendarRow (void);
 static void WriteWeekHeaderLine (void);
 static void WritePostHeaderLine (void);
 static void PrintLeft (char const *s, int width, char pad);
-static void PrintCentered (char const *s, int width, char *pad);
+static void PrintCentered (char const *s, int width, char const *pad);
 static int WriteOneCalLine (int dse, int wd);
 static int WriteOneColLine (int col);
 static void GenerateCalEntries (int col);
@@ -380,7 +381,7 @@ despace(char const *s)
     return buf;
 }
 
-void PrintJSONChar(char c) {
+static void PrintJSONChar(char c) {
     switch(c) {
     case '\b': printf("\\b"); break;
     case '\f': printf("\\f"); break;
@@ -422,7 +423,7 @@ void PrintJSONString(char const *s)
     }
 }
 
-void PrintJSONStringLC(char const *s)
+static void PrintJSONStringLC(char const *s)
 {
     while (*s) {
         switch(*s) {
@@ -466,7 +467,7 @@ void PrintJSONKeyPairString(char const *name, char const *val)
     printf("\",");
 }
 
-void PrintJSONKeyPairDate(char const *name, int dse)
+static void PrintJSONKeyPairDate(char const *name, int dse)
 {
     int y, m, d;
     if (dse == NO_DATE) {
@@ -480,7 +481,7 @@ void PrintJSONKeyPairDate(char const *name, int dse)
 
 }
 
-void PrintJSONKeyPairDateTime(char const *name, int dt)
+static void PrintJSONKeyPairDateTime(char const *name, int dt)
 {
     int y, m, d, h, i, k;
     if (dt == NO_TIME) {
@@ -498,7 +499,7 @@ void PrintJSONKeyPairDateTime(char const *name, int dt)
 
 }
 
-void PrintJSONKeyPairTime(char const *name, int t)
+static void PrintJSONKeyPairTime(char const *name, int t)
 {
     int h, i;
     if (t == NO_TIME) {
@@ -646,7 +647,7 @@ Colorize256(int r, int g, int b, int bg, int clamp)
     int best = -1;
     int best_dist = 0;
     int dist;
-    struct xterm256_colors *cur;
+    struct xterm256_colors const *cur;
     size_t i;
 
     if (clamp) {
@@ -757,7 +758,7 @@ InitMoonsAndShades(void)
 static void
 SetShadeEntry(int dse, char const *shade)
 {
-    int y, m, d;
+    int d;
     int r, g, b;
     /* Don't bother if we're not doing SHADE specials */
     if (!UseBGVTColors) {
@@ -774,7 +775,7 @@ SetShadeEntry(int dse, char const *shade)
     if (r < 0 || g < 0 || b < 0 || r > 255 || g > 255 || b > 255) {
         return;
     }
-    FromDSE(dse, &y, &m, &d);
+    FromDSE(dse, NULL, NULL, &d);
     bgcolor[d][0] = r;
     bgcolor[d][1] = g;
     bgcolor[d][2] = b;
@@ -784,7 +785,7 @@ static void
 SetMoonEntry(int dse, char const *moon)
 {
     int phase;
-    int y, m, d;
+    int d;
     char msg[28];
 
     /* Don't bother unless it's utf-8 */
@@ -803,7 +804,7 @@ SetMoonEntry(int dse, char const *moon)
         /* Bad phase */
         return;
     }
-    FromDSE(dse, &y, &m, &d);
+    FromDSE(dse, NULL, NULL, &d);
     if (msg[0]) {
         snprintf(moons[d], sizeof(moons[d]), "%s %s", moonphase_emojis[phase], msg);
     } else {
@@ -1387,7 +1388,7 @@ static void PrintLeft(char const *s, int width, char pad)
 /*  Center a piece of text                                      */
 /*                                                             */
 /***************************************************************/
-static void PrintCentered(char const *s, int width, char *pad)
+static void PrintCentered(char const *s, int width, char const *pad)
 {
 #ifndef REM_USE_WCHAR
     int len = strlen(s);
@@ -1476,13 +1477,13 @@ static void PrintCentered(char const *s, int width, char *pad)
 static int WriteOneCalLine(int start_dse, int wd)
 {
     int done = 1, i;
-    int y, m, d;
+    int d;
 
     gon();
     DRAW(tb);
     goff();
     for (i=0; i<7; i++) {
-        FromDSE(start_dse+i, &y, &m, &d);
+        FromDSE(start_dse+i, NULL, NULL, &d);
         d -= wd;
         if (CalColumn[i]) {
             Backgroundize(ColToDay[i]);
@@ -1805,6 +1806,18 @@ static void GenerateCalEntries(int col)
                 break;
             case T_Pop:     r=PopOmitContext(&p);     break;
             case T_Push:    r=PushOmitContext(&p);    break;
+            case T_PushVars:
+                r=PushVars(&p);
+                break;
+            case T_PopVars:
+                r=PopVars(&p);
+                break;
+            case T_PushFuncs:
+                r=PushUserFuncs(&p);
+                break;
+            case T_PopFuncs:
+                r=PopUserFuncs(&p);
+                break;
             case T_Preserve: r=DoPreserve(&p);        break;
             case T_Expr: r = DoExpr(&p);              break;
             case T_Translate: r = DoTranslate(&p); break;
@@ -2342,7 +2355,7 @@ static int DoCalRem(ParsePtr p, int col)
     return OK;
 }
 
-static void WriteSimpleEntryProtocol1(CalEntry *e)
+static void WriteSimpleEntryProtocol1(CalEntry const *e)
 {
         if (e->passthru[0]) {
             printf(" %s", e->passthru);
@@ -2782,7 +2795,7 @@ static void WriteCalDays(void)
 /*  This takes into account duration                           */
 /*                                                             */
 /***************************************************************/
-char const *
+static char const *
 CalendarTime(int tim, int duration)
 {
     static char buf[128];
