@@ -23,25 +23,25 @@
 #define E_MISS_END            1
 #define E_MISS_QUOTE          2
 #define E_OP_STK_OVER         3
-/* #define E_VA_STK_OVER         4 */
+#define E_CANT_PARSE_MONTH    4
 #define E_MISS_RIGHT_PAREN    5
 #define E_UNDEF_FUNC          6
 #define E_ILLEGAL_CHAR        7
-/* #define E_EXPECTING_BINOP     8 */
+#define E_CANT_PARSE_WKDAY    8
 #define E_NO_MEM              9
 #define E_BAD_NUMBER         10
-/* #define E_OP_STK_UNDER       11 */
-/* #define E_VA_STK_UNDER       12 */
+#define E_PUSHV_NO_POP       11
+#define E_POPV_NO_PUSH       12
 #define E_CANT_COERCE        13
 #define E_BAD_TYPE           14
 #define E_DATE_OVER          15
-/* #define E_STACK_ERR          16 */
+#define E_POPF_NO_PUSH       16
 #define E_DIV_ZERO           17
 #define E_NOSUCH_VAR         18
 #define E_EOLN               19
 #define E_EOF                20
 #define E_IO_ERR             21
-/* #define E_LINE_2_LONG        22 */
+#define E_PUSHF_NO_POP       22
 #define E_SWERR              23
 #define E_BAD_DATE           24
 #define E_2FEW_ARGS          25
@@ -151,25 +151,25 @@ EXTERN char *ErrMsg[]
 /* E_MISS_END */          "Missing ']'",
 /* E_MISS_QUOTE */        "Missing quote",
 /* E_OP_STK_OVER */       "Expression too complex",
-/* E_VA_STK_OVER */       "",
+/* E_CANT_PARSE_MONTH */  "Invalid month name",
 /* E_MISS_RIGHT_PAREN */  "Missing ')'",
 /* E_UNDEF_FUNC */        "Undefined function",
 /* E_ILLEGAL_CHAR */      "Illegal character",
-/* E_EXPECTING_BINOP */   "Expecting binary operator",
+/* E_CANT_PARSE_WKDAY*/   "Invalid weekday name",
 /* E_NO_MEM */            "Out of memory",
 /* E_BAD_NUMBER */        "Ill-formed number",
-/* E_OP_STK_UNDER */      "",
-/* E_VA_STK_UNDER */      "",
+/* E_PUSHV_NO_POP */      "Warning: PUSH-VARS without matching POP-VARS",
+/* E_POPV_NO_PUSH */      "POP-VARS without matching PUSH-VARS",
 /* E_CANT_COERCE */       "Can't coerce",
 /* E_BAD_TYPE */          "Type mismatch",
 /* E_DATE_OVER */         "Date overflow",
-/* E_STACK_ERR */         "",
+/* E_POPF_NO_PUSH */      "POP-FUNCS without matching PUSH-FUNCS",
 /* E_DIV_ZERO */          "Division by zero",
 /* E_NOSUCH_VAR */        "Undefined variable",
 /* E_EOLN */              "Unexpected end of line",
 /* E_EOF */               "Unexpected end of file",
 /* E_IO_ERR */            "I/O error",
-/* E_LINE_2_LONG */       "",
+/* E_PUSHF_NO_POP */      "Warning: PUSH-FUNCS without matching POP-FUNCS",
 /* E_SWERR */             "Internal error",
 /* E_BAD_DATE */          "Bad date specification",
 /* E_2FEW_ARGS */         "Not enough arguments",
