@@ -114,16 +114,16 @@ static int CheckSafetyAux (struct stat *statbuf);
 static int PopFile (void);
 static int IncludeCmd(char const *);
 
-static unsigned int FnHashFunc(void *x)
+static unsigned int FnHashFunc(void const *x)
 {
-    FilenameHashEntry *e = (FilenameHashEntry *) x;
+    FilenameHashEntry const *e = (FilenameHashEntry const *) x;
     return HashVal_preservecase(e->fname);
 }
 
-static int FnCompareFunc(void *a, void *b)
+static int FnCompareFunc(void const *a, void const *b)
 {
-    FilenameHashEntry *e1 = (FilenameHashEntry *) a;
-    FilenameHashEntry *e2 = (FilenameHashEntry *) b;
+    FilenameHashEntry const *e1 = (FilenameHashEntry const *) a;
+    FilenameHashEntry const *e2 = (FilenameHashEntry const *) b;
     return strcmp(e1->fname, e2->fname);
 }
 
@@ -179,7 +179,7 @@ got_a_fresh_line(void)
     WarnedAboutImplicit = 0;
 }
 
-void set_cloexec(FILE *fp)
+static void set_cloexec(FILE *fp)
 {
     int flags;
     int fd;
@@ -381,7 +381,7 @@ static int ReadLineFromFile(int use_pclose)
 /*  ShouldCache is 1, cache the file                           */
 /*                                                             */
 /***************************************************************/
-int OpenFile(char const *fname)
+static int OpenFile(char const *fname)
 {
     CachedFile *h = CachedFiles;
     int r;
@@ -1151,7 +1151,7 @@ int IncludeFile(char const *fname)
 int GetAccessDate(char const *file)
 {
     struct stat statbuf;
-    struct tm *t1;
+    struct tm const *t1;
 
     if (stat(file, &statbuf)) return -1;
     t1 = localtime(&(statbuf.st_atime));
