@@ -50,11 +50,15 @@
 #include "err.h"
 
 static void DoReminders(void);
+static int DoDebug(ParsePtr p);
+static void ClearLastTriggers(void);
+static int DoBanner(ParsePtr p);
+static void SaveLastTimeTrig(TimeTrig const *t);
 
 /* Macro for simplifying common block so as not to litter code */
 #define OUTPUT(c) do { if (output) { DBufPutc(output, c); } else { putchar(c); } } while(0)
 
-void
+static void
 exitfunc(void)
 {
     /* Kill any execution-time-limiter process */
@@ -177,8 +181,18 @@ int main(int argc, char *argv[])
         }
 
         if (!Hush) {
-            if (DestroyOmitContexts(1))
+            if (DestroyOmitContexts(1)) {
+                FreshLine = 1;
                 Eprint("%s", GetErr(E_PUSH_NOPOP));
+            }
+            if (EmptyVarStack(1)) {
+                FreshLine = 1;
+                Eprint("%s", GetErr(E_PUSHV_NO_POP));
+            }
+            if (EmptyUserFuncStack(1)) {
+                FreshLine = 1;
+                Eprint("%s", GetErr(E_PUSHF_NO_POP));
+            }
             if (!Daemon && !NextMode && !NumTriggered && !NumQueued) {
                 printf("%s\n", GetErr(E_NOREMINDERS));
             } else if (!Daemon && !NextMode && !NumTriggered) {
@@ -231,6 +245,8 @@ PerIterationInit(void)
 {
     ClearGlobalOmits();
     DestroyOmitContexts(1);
+    EmptyVarStack(1);
+    EmptyUserFuncStack(1);
     DestroyVars(0);
     DefaultColorR = -1;
     DefaultColorG = -1;
@@ -362,6 +378,18 @@ static void DoReminders(void)
             case T_Pop:     r=PopOmitContext(&p);     break;
             case T_Preserve: r=DoPreserve(&p);  break;
             case T_Push:    r=PushOmitContext(&p);    break;
+            case T_PushVars:
+                r=PushVars(&p);
+                break;
+            case T_PopVars:
+                r=PopVars(&p);
+                break;
+            case T_PushFuncs:
+                r=PushUserFuncs(&p);
+                break;
+            case T_PopFuncs:
+                r=PopUserFuncs(&p);
+                break;
             case T_Expr: r = DoExpr(&p); break;
             case T_Translate: r = DoTranslate(&p); break;
             case T_RemType: if (tok.val == RUN_TYPE) {
@@ -459,6 +487,15 @@ void FromDSE(int dse, int *y, int *m, int *d)
         try_yr--;
         try_dse -= DaysInYear(try_yr);
     }
+    if (y) {
+        *y = try_yr;
+    }
+
+    /* If all we want is the year, we can quit here */
+    if (!d && !m) {
+        return;
+    }
+
     dse -= try_dse;
 
     t = DaysInMonth(try_mon, try_yr);
@@ -467,9 +504,6 @@ void FromDSE(int dse, int *y, int *m, int *d)
         try_mon++;
         t = DaysInMonth(try_mon, try_yr);
     }
-    if (y) {
-        *y = try_yr;
-    }
     if (m) {
         *m = try_mon;
     }
@@ -1061,7 +1095,7 @@ int PushToken(char const *tok, ParsePtr p)
 int SystemTime(int realtime)
 {
     time_t now;
-    struct tm *t;
+    struct tm const *t;
 
     if (!realtime && (SysTime != -1)) return SysTime;
 
@@ -1101,7 +1135,7 @@ int MinutesPastMidnight(int realtime)
 int SystemDate(int *y, int *m, int *d)
 {
     time_t now;
-    struct tm *t;
+    struct tm const *t;
 
     /* In test mode, always return 6 January 2025 */
     if (TestMode) {
@@ -1275,7 +1309,7 @@ int VerifyEoln(ParsePtr p)
 /*  Set the debug options under program control.               */
 /*                                                             */
 /***************************************************************/
-int DoDebug(ParsePtr p)
+static int DoDebug(ParsePtr p)
 {
     int err;
     int ch;
@@ -1381,7 +1415,7 @@ int DoDebug(ParsePtr p)
 /*  reminder is issued.                                        */
 /*                                                             */
 /***************************************************************/
-int DoBanner(ParsePtr p)
+static int DoBanner(ParsePtr p)
 {
     int err;
     int c;
@@ -1565,7 +1599,8 @@ int CalcMinsFromUTC(int dse, int tim, int *mins, int *isdst)
 /* Convert dse and tim to an Unix tm struct */
     int yr, mon, day;
     int tdiff;
-    struct tm local, utc, *temp;
+    struct tm local, utc;
+    struct tm const * temp;
     time_t loc_t, utc_t;
     int isdst_tmp;
 
@@ -1959,7 +1994,7 @@ FreeTrig(Trigger *t)
     t->infos = NULL;
 }
 
-void
+static void
 ClearLastTriggers(void)
 {
     LastTrigger.expired = 0;
@@ -1994,9 +2029,11 @@ SaveAllTriggerInfo(Trigger const *t, TimeTrig const *tt, int trigdate, int trigt
 {
     SaveLastTrigger(t);
     SaveLastTimeTrig(tt);
-    LastTriggerDate = trigdate;
+    if (trigdate != -1) {
+        LastTriggerDate = trigdate;
+        LastTrigValid = valid;
+    }
     LastTriggerTime = trigtime;
-    LastTrigValid = valid;
 }
 
 void
@@ -2017,7 +2054,7 @@ SaveLastTrigger(Trigger const *t)
     }
 }
 
-void
+static void
 SaveLastTimeTrig(TimeTrig const *t)
 {
     memcpy(&LastTimeTrig, t, sizeof(LastTimeTrig));
