@@ -121,12 +121,9 @@ int PushOmitContext(ParsePtr p)
     context = NEW(OmitContext);
     if (!context) return E_NO_MEM;
 
-    if (GetCurrentFilename()) {
-        context->filename = GetCurrentFilename();
-    } else {
-        context->filename = "";
-    }
+    context->filename = GetCurrentFilename();
     context->lineno = LineNo;
+
     context->numfull = NumFullOmits;
     context->numpart = NumPartialOmits;
     context->weekdaysave = WeekdayOmits;
@@ -242,7 +239,7 @@ int IsOmitted(int dse, int localomit, char const *omitfunc, int *omit)
         return OK;
     }
 
-    FromDSE(dse, &y, &m, &d);
+    FromDSE(dse, NULL, &m, &d);
     if (BexistsIntArray(PartialOmitArray, NumPartialOmits, (m << 5) + d)) {
         *omit = 1;
         return OK;
