@@ -47,32 +47,29 @@ int DoFrename (ParsePtr p);
 void UnsetAllUserFuncs(void);
 void ProduceCalendar (void);
 char const *SimpleTime (int tim);
-char const *CalendarTime (int tim, int duration);
 int DoRem (ParsePtr p);
 int DoFlush (ParsePtr p);
 void DoExit (ParsePtr p);
 int ParseRem (ParsePtr s, Trigger *trig, TimeTrig *tim);
-int TriggerReminder (ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queued, DynamicBuffer *output);
-int ShouldTriggerReminder (Trigger *t, TimeTrig *tim, int dse, int *err);
-int DoSubst (ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig *tt, int dse, int mode);
+int TriggerReminder (ParsePtr p, Trigger *t, TimeTrig const *tim, int dse, int is_queued, DynamicBuffer *output);
+int ShouldTriggerReminder (Trigger const *t, TimeTrig const *tim, int dse, int *err);
+int DoSubst (ParsePtr p, DynamicBuffer *dbuf, Trigger *t, TimeTrig const *tt, int dse, int mode);
 int DoSubstFromString (char const *source, DynamicBuffer *dbuf, int dse, int tim);
 int ParseLiteralDateOrTime (char const **s, int *dse, int *tim);
-int ParseLiteralTime (char const **s, int *tim);
 expr_node *parse_expression(char const **e, int *r, Var *locals);
 
 int evaluate_expression(expr_node *node, Value *locals, Value *ans, int *nonconst);
 int evaluate_expr_node(expr_node *node, Value *locals, Value *ans, int *nonconst);
 int truthy(Value const *v);
 
-void print_expr_tree(expr_node *node, FILE *fp);
 void unlimit_execution_time(void);
 expr_node *free_expr_tree(expr_node *node);
+expr_node *clone_expr_tree(expr_node const *node, int *r);
 int EvalExpr (char const **e, Value *v, ParsePtr p);
 int DoCoerce (char type, Value *v);
 char const *PrintValue  (Value *v, FILE *fp);
 int CopyValue (Value *dest, const Value *src);
 int ReadLine (void);
-int OpenFile (char const *fname);
 int DoInclude (ParsePtr p, enum TokTypes tok);
 int DoIncludeCmd (ParsePtr p);
 int IncludeFile (char const *fname);
@@ -109,8 +106,6 @@ int DoEndif (ParsePtr p);
 int DoIfTrig (ParsePtr p);
 int ShouldIgnoreLine (void);
 int VerifyEoln (ParsePtr p);
-int DoDebug (ParsePtr p);
-int DoBanner (ParsePtr p);
 int DoRun (ParsePtr p);
 int DoExpr (ParsePtr p);
 int DoTranslate (ParsePtr p);
@@ -124,13 +119,12 @@ int PushOmitContext (ParsePtr p);
 int PopOmitContext (ParsePtr p);
 int IsOmitted (int dse, int localomit, char const *omitfunc, int *omit);
 int DoOmit (ParsePtr p);
-int QueueReminder (ParsePtr p, Trigger *trig, TimeTrig *tim, char const *sched);
+int QueueReminder (ParsePtr p, Trigger *trig, TimeTrig const *tim, char const *sched);
 void HandleQueuedReminders (void);
 char const *FindInitialToken (Token *tok, char const *s);
 void FindToken (char const *s, Token *tok);
-void FindNumericToken (char const *s, Token *t);
 int ComputeTrigger (int today, Trigger *trig, TimeTrig *tim, int *err, int save_in_globals);
-int ComputeTriggerNoAdjustDuration (int today, Trigger *trig, TimeTrig *tim, int *err, int save_in_globals, int duration_days);
+int ComputeTriggerNoAdjustDuration (int today, Trigger *trig, TimeTrig const *tim, int *err, int save_in_globals, int duration_days);
 int AdjustTriggerForDuration(int today, int r, Trigger *trig, TimeTrig *tim, int save_in_globals);
 char *StrnCpy (char *dest, char const *source, int n);
 
@@ -150,12 +144,16 @@ void strtolower(char *s);
 
 Var *FindVar (char const *str, int create);
 SysVar *FindSysVar (char const *name);
-int DeleteVar (char const *str);
 int SetVar (char const *str, Value const *val, int nonconst_expr);
-int GetVarValue (char const *str, Value *val);
 int DoSet  (Parser *p);
 int DoUnset  (Parser *p);
 int DoDump (ParsePtr p);
+int PushVars(ParsePtr p);
+int EmptyVarStack(int print_unmatched);
+int PopVars(ParsePtr p);
+int PushUserFuncs(ParsePtr p);
+int EmptyUserFuncStack(int print_unmatched);
+int PopUserFuncs(ParsePtr p);
 void DumpVarTable (int dump_constness);
 void DumpUnusedVars(void);
 void DestroyVars (int all);
@@ -164,7 +162,6 @@ int DoPreserve  (Parser *p);
 int DoSatRemind (Trigger *trig, TimeTrig *tt, ParsePtr p);
 int DoMsgCommand (char const *cmd, char const *msg, int is_queued);
 int ParseNonSpaceChar (ParsePtr p, int *err, int peek);
-unsigned int HashVal_ignorecase(char const *str);
 unsigned int HashVal_preservecase(char const *str);
 int DateOK (int y, int m, int d);
 BuiltinFunc *FindBuiltinFunc (char const *name);
@@ -175,10 +172,6 @@ int UserFuncExists (char const *fn);
 void DSEToHeb (int dse, int *hy, int *hm, int *hd);
 int HebNameToNum (char const *mname);
 char const *HebMonthName (int m, int y);
-int RoshHashana (int i);
-long DaysToHebYear (int y);
-int DaysInHebYear (int y);
-char const *DaysInHebMonths (int ylen);
 int HebToDSE (int hy, int hm, int hd);
 int GetValidHebDate (int yin, int min, int din, int adarbehave, int *mout, int *dout, int yahr);
 int GetNextHebrewDate (int dsestart, int hm, int hd, int yahr, int adarbehave, int *ans);
@@ -199,9 +192,7 @@ void PurgeEchoLine(char const *fmt, ...);
 void FreeTrig(Trigger *t);
 void AppendTag(DynamicBuffer *buf, char const *s);
 char const *SynthesizeTag(void);
-void ClearLastTriggers(void);
 void SaveLastTrigger(Trigger const *t);
-void SaveLastTimeTrig(TimeTrig const *t);
 void SaveAllTriggerInfo(Trigger const *t, TimeTrig const *tt, int trigdate, int trigtime, int valid);
 
 void PerIterationInit(void);
@@ -210,13 +201,9 @@ char const *Colorize(int r, int g, int b, int bg, int clamp);
 void PrintJSONString(char const *s);
 void PrintJSONKeyPairInt(char const *name, int val);
 void PrintJSONKeyPairString(char const *name, char const *val);
-void PrintJSONKeyPairDate(char const *name, int dse);
-void PrintJSONKeyPairDateTime(char const *name, int dt);
-void PrintJSONKeyPairTime(char const *name, int t);
 void System(char const *cmd, int queued);
 int ShellEscape(char const *in, DynamicBuffer *out);
 int AddGlobalOmit(int dse);
-void set_lat_and_long_from_components(void);
 void set_components_from_lat_and_long(void);
 
 void DebugExitFunc(void);
@@ -226,7 +213,6 @@ int GetTerminalBackground(void);
 char const *get_day_name(int wkday);
 char const *get_month_name(int mon);
 
-void set_cloexec(FILE *fp);
 int push_call(char const *filename, char const *func, int lineno, int lineno_start);
 void clear_callstack(void);
 int print_callstack(FILE *fp);
@@ -279,12 +265,8 @@ void print_escaped_string(FILE *fp, char const *s);
 void print_escaped_string_helper(FILE *fp, char const *s, int esc_for_remind, int json);
 void GenerateSysvarTranslationTemplates(void);
 void TranslationTemplate(char const *msg);
-TrigInfo *NewTrigInfo(char const *i);
-void FreeTrigInfo(TrigInfo *ti);
 void FreeTrigInfoChain(TrigInfo *ti);
 int AppendTrigInfo(Trigger *t, char const *info);
-int TrigInfoHeadersAreTheSame(char const *i1, char const *i2);
-int TrigInfoIsValid(char const *info);
 char const *FindTrigInfo(Trigger *t, char const *header);
 void WriteJSONInfoChain(TrigInfo *ti);
 char const *line_range(int lineno_start, int lineno);
