@@ -27,11 +27,11 @@
    executes 'return' if an initial non-numeric char is found. */
 #define PARSENUM(var, string) \
 if (!isdigit(*(string))) return; \
-var = 0; \
+(var) = 0;                       \
 while (isdigit(*(string))) { \
-    var *= 10; \
-    var += *(string) - '0'; \
-    string++; \
+    (var) *= 10;             \
+    (var) += *(string) - '0';                   \
+    (string)++;                                 \
 }
 
 /* The big array holding all recognized (literal) tokens in reminder file.
@@ -90,12 +90,16 @@ Token TokArray[] = {
     { "omit",           4,      T_Omit,         0 },
     { "omitfunc",       8,      T_OmitFunc,     0 },
     { "once",           4,      T_Once,         0 },
+    { "pop-funcs",      9,      T_PopFuncs,     0 },
     { "pop-omit-context", 3,    T_Pop,          0 },
+    { "pop-vars",       8,      T_PopVars,      0 },
     { "preserve",       8,      T_Preserve,     0 },
     { "priority",       8,      T_Priority,     0 },
     { "ps",             2,      T_RemType,      PS_TYPE },
-    { "psfile", 6,      T_RemType,      PSF_TYPE },
+    { "psfile",         6,      T_RemType,      PSF_TYPE },
+    { "push-funcs",     10,     T_PushFuncs,    0 },
     { "push-omit-context", 4,   T_Push,         0 },
+    { "push-vars",      9,      T_PushVars,     0 },
     { "rem",            3,      T_Rem,          0 },
     { "run",            3,      T_RemType,      RUN_TYPE },
     { "satisfy",        7,      T_RemType,      SAT_TYPE },
@@ -122,6 +126,7 @@ Token TokArray[] = {
 };
 
 static int TokStrCmp (Token const *t, char const *s);
+static void FindNumericToken(char const *s, Token *t);
 
 static void
 init_token(Token *t)
@@ -247,7 +252,7 @@ void FindToken(char const *s, Token *tok)
 /*  Rep - *n                                                   */
 /*                                                             */
 /***************************************************************/
-void FindNumericToken(char const *s, Token *t)
+static void FindNumericToken(char const *s, Token *t)
 {
     int mult = 1, hour, min;
     char const *s_orig = s;
@@ -443,7 +448,7 @@ static int TokStrCmp(Token const *t, char const *s)
 }
 
 static void
-print_token(Token *tok)
+print_token(Token const *tok)
 {
     if (tok->MinLen < (int) strlen(tok->name)) {
         printf("%.*s\n", tok->MinLen, tok->name);
@@ -455,7 +460,7 @@ void
 print_remind_tokens(void)
 {
     int i;
-    Token *tok;
+    Token const *tok;
     int num = (int) (sizeof(TokArray) / sizeof(TokArray[0]));
     printf("# Remind Tokens\n\n");
     for (i=0; i<num; i++) {
