@@ -29,8 +29,10 @@
 
 static int DSEYear(int dse);
 static int DSEMonth(int dse);
-static int NextSimpleTrig(int startdate, Trigger *trig, int *err);
+static int NextSimpleTrig(int startdate, Trigger const *trig, int *err);
 static int GetNextTriggerDate(Trigger *trig, int start, int *err, int *nextstart);
+static int TrigInfoIsValid(char const *info);
+static int TrigInfoHeadersAreTheSame(char const *i1, char const *i2);
 
 /***************************************************************/
 /*                                                             */
@@ -44,7 +46,7 @@ static int GetNextTriggerDate(Trigger *trig, int start, int *err, int *nextstart
 /*  so that dates with a REP can be handled properly.          */
 /*                                                             */
 /***************************************************************/
-static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
+static int NextSimpleTrig(int startdate, Trigger const *trig, int *err)
 {
     int typ = 0;
     int d, m, y, j, d2, m2, y2;
@@ -529,7 +531,7 @@ int ComputeTrigger(int today, Trigger *trig, TimeTrig *tim,
 /*  duration.                                                  */
 /*                                                             */
 /***************************************************************/
-int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
+int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig const *tim,
                                    int *err, int save_in_globals, int duration_days)
 {
     int nattempts = 0,
@@ -541,6 +543,7 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
     trig->expired = 0;
     if (save_in_globals) {
         LastTrigValid = 0;
+        LastTriggerDate = -1;
     }
 
     /* Assume everything works */
@@ -579,7 +582,6 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
 
     while (nattempts++ < TRIG_ATTEMPTS) {
         result = GetNextTriggerDate(trig, start, err, &nextstart);
-
         /* If there's an error, die immediately */
         if (*err) return -1;
         if (result == -1) {
@@ -635,8 +637,9 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
             trig->rep == NO_REP) {
             trig->expired = 1;
             if (DebugFlag & DB_PRTTRIG) {
-                fprintf(ErrFp, "%s(%s): %s\n",
-                        GetCurrentFilename(), line_range(LineNoStart, LineNo), GetErr(E_EXPIRED));
+                FromDSE(result, &y, &m, &d);
+                fprintf(ErrFp, "%s(%s): %s: %04d-%02d-%02d\n",
+                        GetCurrentFilename(), line_range(LineNoStart, LineNo), GetErr(E_EXPIRED), y, m+1, d);
             }
             if (save_in_globals) {
                 LastTriggerDate = result;
@@ -682,7 +685,7 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
 /*  Returns NULL if memory allocation fails.                   */
 /*                                                             */
 /***************************************************************/
-TrigInfo *
+static TrigInfo *
 NewTrigInfo(char const *i)
 {
     TrigInfo *ti = malloc(sizeof(TrigInfo));
@@ -706,7 +709,7 @@ NewTrigInfo(char const *i)
 /*  Free a TrigInfo objects.                                   */
 /*                                                             */
 /***************************************************************/
-void
+static void
 FreeTrigInfo(TrigInfo *ti)
 {
     if (ti->info) {
@@ -773,7 +776,7 @@ AppendTrigInfo(Trigger *t, char const *info)
     return OK;
 }
 
-int
+static int
 TrigInfoHeadersAreTheSame(char const *i1, char const *i2)
 {
     char const *c1 = strchr(i1, ':');
@@ -784,7 +787,7 @@ TrigInfoHeadersAreTheSame(char const *i1, char const *i2)
     return 0;
 }
 
-int
+static int
 TrigInfoIsValid(char const *info)
 {
     char const *t;
