@@ -37,14 +37,16 @@ static int IntMax = INT_MAX;
 
 static hash_table VHashTbl;
 static int SetSysVarHelper(SysVar *v, Value *value);
+static unsigned int HashVal_ignorecase(char const *str);
+static void set_lat_and_long_from_components(void);
 
-static unsigned int VarHashFunc(void *x)
+static unsigned int VarHashFunc(void const *x)
 {
-    Var *v = (Var *) x;
+    Var const *v = (Var const *) x;
     return HashVal_ignorecase(v->name);
 }
 
-static int VarCompareFunc(void *a, void *b)
+static int VarCompareFunc(void const *a, void const *b)
 {
     Var *x = (Var *) a;
     Var *y = (Var *) b;
@@ -153,7 +155,7 @@ static int latitude_longitude_func(int do_set, Value *val, double *var, double m
         if (loc) {
             setlocale(LC_NUMERIC, "C");
         }
-        snprintf(buf, sizeof(buf), "%f", *var);
+        snprintf(buf, sizeof(buf), "%.8f", *var);
         if (loc) {
             setlocale(LC_NUMERIC, loc);
         }
@@ -285,7 +287,7 @@ static int trig_until_func(int do_set, Value *val)
 
 static int trig_day_func(int do_set, Value *val)
 {
-    int y, m, d;
+    int d;
     UNUSED(do_set);
     val->type = INT_TYPE;
     if (!LastTrigValid) {
@@ -293,7 +295,7 @@ static int trig_day_func(int do_set, Value *val)
         return OK;
     }
 
-    FromDSE(LastTriggerDate, &y, &m, &d);
+    FromDSE(LastTriggerDate, NULL, NULL, &d);
     val->v.val = d;
     return OK;
 }
@@ -312,7 +314,7 @@ static int timet_is_64_func(int do_set, Value *val)
 
 static int trig_mon_func(int do_set, Value *val)
 {
-    int y, m, d;
+    int m;
     UNUSED(do_set);
     val->type = INT_TYPE;
     if (!LastTrigValid) {
@@ -320,14 +322,14 @@ static int trig_mon_func(int do_set, Value *val)
         return OK;
     }
 
-    FromDSE(LastTriggerDate, &y, &m, &d);
+    FromDSE(LastTriggerDate, NULL, &m, NULL);
     val->v.val = m+1;
     return OK;
 }
 
 static int trig_year_func(int do_set, Value *val)
 {
-    int y, m, d;
+    int y;
     UNUSED(do_set);
     val->type = INT_TYPE;
     if (!LastTrigValid) {
@@ -335,7 +337,7 @@ static int trig_year_func(int do_set, Value *val)
         return OK;
     }
 
-    FromDSE(LastTriggerDate, &y, &m, &d);
+    FromDSE(LastTriggerDate, &y, NULL, NULL);
     val->v.val = y;
     return OK;
 }
@@ -362,30 +364,30 @@ static int today_date_func(int do_set, Value *val)
 }
 static int today_day_func(int do_set, Value *val)
 {
-    int y, m, d;
+    int d;
     UNUSED(do_set);
     val->type = INT_TYPE;
-    FromDSE(DSEToday, &y, &m, &d);
+    FromDSE(DSEToday, NULL, NULL, &d);
     val->v.val = d;
     return OK;
 }
 
 static int today_mon_func(int do_set, Value *val)
 {
-    int y, m, d;
+    int m;
     UNUSED(do_set);
     val->type = INT_TYPE;
-    FromDSE(DSEToday, &y, &m, &d);
+    FromDSE(DSEToday, NULL, &m, NULL);
     val->v.val = m+1;
     return OK;
 }
 
 static int today_year_func(int do_set, Value *val)
 {
-    int y, m, d;
+    int y;
     UNUSED(do_set);
     val->type = INT_TYPE;
-    FromDSE(DSEToday, &y, &m, &d);
+    FromDSE(DSEToday, &y, NULL, NULL);
     val->v.val = y;
     return OK;
 }
@@ -523,7 +525,7 @@ static int time_sep_func(int do_set, Value *val)
 /*  Given a string, compute the hash value case-insensitively  */
 /*                                                             */
 /***************************************************************/
-unsigned int HashVal_ignorecase(char const *str)
+static unsigned int HashVal_ignorecase(char const *str)
 {
     unsigned int h = 0, high;
     while(*str) {
@@ -576,7 +578,7 @@ Var *FindVar(char const *str, int create)
 /*  string and delete it.                                      */
 /*                                                             */
 /***************************************************************/
-int DeleteVar(char const *str)
+static int DeleteVar(char const *str)
 {
     Var *v;
 
@@ -622,27 +624,6 @@ int SetVar(char const *str, Value const *val, int nonconst_expr)
     return OK;
 }
 
-/***************************************************************/
-/*                                                             */
-/*  GetVarValue                                                */
-/*                                                             */
-/*  Get a copy of the value of the variable.                   */
-/*                                                             */
-/***************************************************************/
-int GetVarValue(char const *str, Value *val)
-{
-    Var *v;
-
-    v=FindVar(str, 0);
-
-    if (!v) {
-        Eprint("%s: `%s'", GetErr(E_NOSUCH_VAR), str);
-        return E_NOSUCH_VAR;
-    }
-    v->used_since_set = 1;
-    return CopyValue(val, &v->v);
-}
-
 /***************************************************************/
 /*                                                             */
 /*  DoSet - set a variable.                                    */
@@ -1098,14 +1079,263 @@ static SysVar SysVarArr[] = {
 };
 
 #define NUMSYSVARS ( sizeof(SysVarArr) / sizeof(SysVar) )
+
+typedef struct pushed_vars {
+    struct pushed_vars *next;
+    char const *filename;
+    int lineno;
+    int num_sysvars;
+    int num_vars;
+    int alloc_sysvars;
+    int alloc_vars;
+    PushedSysvar *sysvars;
+    Var *vars;
+} PushedVars;
+
+static void free_pushedvars(PushedVars *pv);
+
+static PushedVars *VarStack = NULL;
+
+int EmptyVarStack(int print_unmatched)
+{
+    int j=0;
+    PushedVars *next;
+    while(VarStack) {
+        if (print_unmatched) {
+            Wprint(tr("Unmatched PUSH-VARS at %s(%d)"),
+                   VarStack->filename,
+                   VarStack->lineno);
+        }
+        j++;
+        next = VarStack->next;
+        free_pushedvars(VarStack);
+        VarStack = next;
+    }
+    return j;
+}
+
+static int add_sysvar_to_push(char const *name, PushedVars *pv)
+{
+    int n = pv->alloc_sysvars;
+    if (*name == '$') {
+        name++;
+    }
+    SysVar *v = FindSysVar(name);
+    if (!v) {
+        return E_NOSUCH_VAR;
+    }
+    if (!v->modifiable) {
+        Eprint("%s: `$%s'", GetErr(E_CANT_MODIFY), v->name);
+        return E_CANT_MODIFY;
+    }
+    if (!n) {
+        n = 4;
+        pv->sysvars = malloc(n * sizeof(PushedSysvar));
+        pv->alloc_sysvars = n;
+    } else {
+        if (pv->num_sysvars >= n) {
+            n *= 2;
+            pv->sysvars = realloc(pv->sysvars, n * sizeof(PushedSysvar));
+            pv->alloc_sysvars = n;
+        }
+    }
+    if (!pv->sysvars) {
+        return E_NO_MEM;
+    }
+    n = pv->num_sysvars;
+    pv->num_sysvars++;
+    pv->sysvars[n].name = v->name;
+    pv->sysvars[n].v.type = ERR_TYPE;
+    return GetSysVar(name, &(pv->sysvars[n].v));
+}
+
+static int add_var_to_push(char const *name, PushedVars *pv)
+{
+    int n = pv->alloc_vars;
+    if (!n) {
+        n = 4;
+        pv->vars = malloc(n * sizeof(Var));
+        pv->alloc_vars = n;
+    } else {
+        if (pv->num_vars >= n) {
+            n *= 2;
+            pv->vars = realloc(pv->vars, n * sizeof(Var));
+            pv->alloc_vars = n;
+        }
+    }
+    if (!pv->vars) {
+        return E_NO_MEM;
+    }
+    n = pv->num_vars;
+    pv->num_vars++;
+    Var *v = FindVar(name, 0);
+    Var *dest = &(pv->vars[n]);
+    int r = OK;
+    if (!v) {
+        StrnCpy(dest->name, name, VAR_NAME_LEN);
+        dest->preserve = 0;
+        dest->is_constant = 0;
+        dest->used_since_set = 0;
+        dest->filename = NULL;
+        dest->lineno = -1;
+        dest->v.type = ERR_TYPE;
+        dest->v.v.val = E_NOSUCH_VAR;
+    } else {
+        StrnCpy(dest->name, v->name, VAR_NAME_LEN);
+        dest->preserve = v->preserve;
+        dest->is_constant = v->is_constant;
+        dest->used_since_set = v->used_since_set;
+        dest->filename = v->filename;
+        dest->lineno = v->lineno;
+        r = CopyValue(&(dest->v), &(v->v));
+        /* Pretend we've used v */
+        v->used_since_set = 1;
+    }
+    return r;
+}
+
+static void free_pushedvars(PushedVars *pv)
+{
+    int i;
+    for (i=0; i<pv->num_sysvars; i++) {
+        DestroyValue(pv->sysvars[i].v);
+    }
+    for (i=0; i<pv->num_vars; i++) {
+        DestroyValue(pv->vars[i].v);
+    }
+    if (pv->sysvars) {
+        free(pv->sysvars);
+    }
+    if (pv->vars) {
+        free(pv->vars);
+    }
+    free(pv);
+}
+
+int
+PushVars(ParsePtr p)
+{
+    int r;
+    DynamicBuffer buf;
+    char const *name;
+
+    PushedVars *pv = NEW(PushedVars);
+    if (!pv) {
+        return E_NO_MEM;
+    }
+    pv->next = NULL;
+    pv->filename = GetCurrentFilename();
+    pv->lineno = LineNo;
+    pv->num_sysvars = 0;
+    pv->num_vars = 0;
+    pv->alloc_sysvars = 0;
+    pv->alloc_vars = 0;
+    pv->sysvars = NULL;
+    pv->vars = NULL;
+
+    DBufInit(&buf);
+    while(1) {
+        r = ParseIdentifier(p, &buf);
+        if (r == E_EOLN) {
+            break;
+        }
+        if (r) {
+            DBufFree(&buf);
+            free_pushedvars(pv);
+            return r;
+        }
+        name = DBufValue(&buf);
+        if (*name == '$') {
+            r = add_sysvar_to_push(name+1, pv);
+        } else {
+            r = add_var_to_push(name, pv);
+        }
+        DBufFree(&buf);
+        if (r != OK) {
+            free_pushedvars(pv);
+            return r;
+        }
+    }
+    if ((pv->num_vars + pv->num_sysvars) == 0) {
+        free_pushedvars(pv);
+        return E_EOLN;
+    }
+    pv->next = VarStack;
+    VarStack = pv;
+    return OK;
+}
+
+int
+PopVars(ParsePtr p)
+{
+    int r = VerifyEoln(p);
+    int i;
+    int ret = OK;
+    PushedVars *pv = VarStack;
+    if (r != OK) {
+        return r;
+    }
+    if (!pv) {
+        return E_POPV_NO_PUSH;
+    }
+    VarStack = VarStack->next;
+    if (strcmp(pv->filename, GetCurrentFilename())) {
+        Wprint(tr("POP-VARS at %s:%d matches PUSH-VARS in different file: %s:%d"), GetCurrentFilename(), LineNo, pv->filename, pv->lineno);
+    }
+
+    /* Pop the sysvars */
+    for (i=0; i<pv->num_sysvars; i++) {
+        r = SetSysVar(pv->sysvars[i].name, &(pv->sysvars[i].v));
+        if (r != OK) {
+            ret = r;
+        }
+    }
+
+    /* Pop the vars */
+    for (i=0; i<pv->num_vars; i++) {
+        Var *src = &(pv->vars[i]);
+        if (src->v.type == ERR_TYPE && src->v.v.val == E_NOSUCH_VAR) {
+            /* Delete the variable if it exists */
+            (void) DeleteVar(src->name);
+        } else {
+            Var *dest = FindVar(src->name, 0);
+            if ((DebugFlag & DB_UNUSED_VARS) && dest && !dest->used_since_set) {
+                Eprint(tr("`%s' UNSET without being used (previous SET: %s:%d)"), dest->name, dest->filename, dest->lineno);
+            }
+            if (!dest) {
+                dest = FindVar(src->name, 1);
+            }
+            if (!dest) {
+                ret = E_NO_MEM;
+                continue;
+            }
+            dest->preserve = src->preserve;
+            dest->is_constant = src->is_constant;
+            dest->used_since_set = src->used_since_set;
+            dest->filename = src->filename;
+            dest->lineno = src->lineno;
+            DestroyValue(dest->v);
+
+            /* Destructively copy value */
+            dest->v = src->v;
+
+            /* Make sure free_pushedvars doesn't destroy our value! */
+            src->v.type = ERR_TYPE;
+            src->v.v.val = 0;
+        }
+    }
+    free_pushedvars(pv);
+    return ret;
+}
+
 static void DumpSysVar (char const *name, const SysVar *v);
 
-static int SetTranslatableVariable(SysVar *v, Value *value)
+static int SetTranslatableVariable(SysVar const *v, Value const *value)
 {
     return InsertTranslation((char const *) v->value, value->v.str);
 }
 
-static int GetTranslatableVariable(SysVar *v, Value *value)
+static int GetTranslatableVariable(SysVar const *v, Value *value)
 {
     char const *translated = tr((char const *) v->value);
     if (translated) {
@@ -1256,7 +1486,7 @@ SysVar *FindSysVar(char const *name)
 void DumpSysVarByName(char const *name)
 {
     size_t i;
-    SysVar *v;
+    SysVar const *v;
 
     if (!name || !*name) {
         for (i=0; i<NUMSYSVARS; i++) DumpSysVar(name, SysVarArr + i);
@@ -1333,7 +1563,7 @@ static void DumpSysVar(char const *name, const SysVar *v)
     return;
 }
 
-void
+static void
 set_lat_and_long_from_components(void)
 {
     Latitude = (double) LatDeg + ((double) LatMin) / 60.0 + ((double) LatSec) / 3600.0;
